from swatchtime import SwatchTime

def main():
	print(SwatchTime().get())

main()